Authors of Sesame
-----------------

The authors of Sesame are 
 * Benoit Gaury (NIST / University of Maryland)
 * Paul M. Haney (NIST)

Benoit Gaury acknowledges support under the Cooperative Research Agreement
between the University of Maryland and the National Institute of Standards and
Technology Center for Nanoscale Science and Technology, Award 70NANB14H209,
through the University of Maryland.
